@@ -41,12 +41,12 @@ static GSList *drivers = NULL;
 static GSList *watches = NULL;
 
 struct io_watch {
-	gpointer object;
+	void *object;
 	obex_object_io_func func;
-	gpointer user_data;
+	void *user_data;
 };
 
-void obex_object_set_io_flags(gpointer object, int flags, int err)
+void obex_object_set_io_flags(void *object, int flags, int err)
 {
 	GSList *l;
 
@@ -67,7 +67,7 @@ void obex_object_set_io_flags(gpointer object, int flags, int err)
 	}
 }
 
-static struct io_watch *find_io_watch(gpointer object)
+static struct io_watch *find_io_watch(void *object)
 {
 	GSList *l;
 
@@ -81,7 +81,7 @@ static struct io_watch *find_io_watch(gpointer object)
 	return NULL;
 }
 
-static void reset_io_watch(gpointer object)
+static void reset_io_watch(void *object)
 {
 	struct io_watch *watch;
 
@@ -93,8 +93,8 @@ static void reset_io_watch(gpointer object)
 	g_free(watch);
 }
 
-static int set_io_watch(gpointer object, obex_object_io_func func,
-				gpointer user_data)
+static int set_io_watch(void *object, obex_object_io_func func,
+				void *user_data)
 {
 	struct io_watch *watch;
 
@@ -117,15 +117,19 @@ static int set_io_watch(gpointer object, obex_object_io_func func,
 	return 0;
 }
 
-struct obex_mime_type_driver *obex_mime_type_driver_find(const guint8 *target, const char *mimetype)
+static struct obex_mime_type_driver *find_driver(const uint8_t *target,
+				const char *mimetype, const uint8_t *who,
+				unsigned int who_size)
 {
 	GSList *l;
 
 	for (l = drivers; l; l = l->next) {
 		struct obex_mime_type_driver *driver = l->data;
 
-		if (driver->target && target &&
-				memcmp(target, driver->target, TARGET_SIZE))
+		if (memcmp0(target, driver->target, TARGET_SIZE))
+			continue;
+
+		if (memcmp0(who, driver->who, who_size))
 			continue;
 
 		if (g_strcmp0(mimetype, driver->mimetype) == 0)
@@ -135,6 +139,33 @@ struct obex_mime_type_driver *obex_mime_type_driver_find(const guint8 *target, c
 	return NULL;
 }
 
+struct obex_mime_type_driver *obex_mime_type_driver_find(const uint8_t *target,
+				const char *mimetype, const uint8_t *who,
+				unsigned int who_size)
+{
+	struct obex_mime_type_driver *driver;
+
+	driver = find_driver(target, mimetype, who, who_size);
+	if (driver == NULL) {
+		if (who != NULL) {
+			/* Fallback to non-who specific */
+			driver = find_driver(target, mimetype, NULL, 0);
+			if (driver != NULL)
+				return driver;
+		}
+
+		if (mimetype != NULL)
+			/* Fallback to target default */
+			driver = find_driver(target, NULL, NULL, 0);
+
+		if (driver == NULL)
+			/* Fallback to general default */
+			driver = find_driver(NULL, NULL, NULL, 0);
+	}
+
+	return driver;
+}
+
 int obex_mime_type_driver_register(struct obex_mime_type_driver *driver)
 {
 	if (!driver) {
@@ -142,8 +173,10 @@ int obex_mime_type_driver_register(struct obex_mime_type_driver *driver)
 		return -EINVAL;
 	}
 
-	if (obex_mime_type_driver_find(driver->target, driver->mimetype)) {
-		error("Permission denied: %s could not be registered", driver->mimetype);
+	if (find_driver(driver->target, driver->mimetype,
+					driver->who, driver->who_size)) {
+		error("Permission denied: %s could not be registered",
+				driver->mimetype);
 		return -EPERM;
 	}
 
